@@ -1,4 +1,4 @@
-import requests
+import httpx
 
 try:
     import ujson as json
@@ -7,8 +7,6 @@ except ModuleNotFoundError:
 
 from nonebot import logger
 
-
-
 def Lolicon(N:int = 1, Tag:str = "", R18:int = 0):
     if Tag:
         tag_list = Tag.strip().split()
@@ -33,7 +31,7 @@ def Lolicon(N:int = 1, Tag:str = "", R18:int = 0):
         N = 1
         msg += f"Bot_NICKNAME接收到了奇怪的数量参数，不过Bot_NICKNAME送你一张随机{'r18'if R18 else ''}{tag[5:]}色图。"
     logger.info(f"正在从 Lolicon API 获取图片。")
-    resp = requests.get(f"https://api.lolicon.app/setu/v2?num={N}&r18={R18}{tag}&excludeAI=1")
+    resp = httpx.get(f"https://api.lolicon.app/setu/v2?num={N}&r18={R18}{tag}&excludeAI=1")
     if resp.status_code == 200:
         resp = resp.text
         resp = ''.join(x for x in resp if x.isprintable())
